@@ -13,6 +13,24 @@ from imap_cli import const
 
 
 app_name = os.path.splitext(os.path.basename(__file__))[0]
+DEFAULT_CONFIG = {
+    'hostname': 'imap.example.org',
+    'username': 'username',
+    'password': 'secret',
+    'ssl': True,
+
+    'limit': 10,
+    'format_list': "".join([
+        "\n",
+        "ID:         {mail_id}\n",
+        "Flags:      {flags}\n",
+        "From:       {mail_from}\n",
+        "To:         {to}\n",
+        "Date:       {date}\n",
+        "Subject:    {subject}",
+    ]),
+    'format_status': "{directory:>20} : {count:>5} Mails - {unseen:>5} Unseen - {recent:>5} Recent"
+}
 log = logging.getLogger(app_name)
 
 
@@ -28,6 +46,22 @@ class Ctx(object):
     format_list = None
 
 
+def new_context(config=None):
+    ctx = Ctx()
+    if config is None:
+        log.debug("Loading default configuration")
+        config = DEFAULT_CONFIG
+    else:
+        log.debug("Loading custom configuration")
+
+    for key, value in config.items():
+        setattr(ctx, key, value)
+    for key, value in DEFAULT_CONFIG.items():
+        if getattr(ctx, key) is None:
+            setattr(ctx, key, value)
+    return ctx
+
+
 def new_context_from_file(config_filename=None):
     ctx = Ctx()
     if config_filename is None:
