@@ -12,7 +12,7 @@ Options:
     --version                   Print program version.
 
 ----
-imap-cli-flag 0.2
+imap-cli-flag 0.3
 Copyright (C) 2014 Romain Soufflet
 License MIT
 This is free software: you are free to change and redistribute it.
@@ -27,7 +27,8 @@ import docopt
 
 from imap_cli import config
 from imap_cli import const
-from imap_cli import helpers
+from imap_cli.imap import connection
+from imap_cli.imap import flag as imap_flag
 
 
 log = logging.getLogger('imap-cli-flag')
@@ -35,11 +36,11 @@ log = logging.getLogger('imap-cli-flag')
 
 def flag(ctx, mail_id, flags, directory=const.DEFAULT_DIRECTORY):
     status, mail_count = ctx.mail_account.select(directory)
-    if status != 'OK':
+    if status != const.STATUS_OK:
         log.warn(u'Cannot access directory {}'.format(directory))
         return
     for flag in flags:
-        helpers.flag(ctx, mail_id, r'({})'.format(flag))
+        imap_flag.flag(ctx, mail_id, r'({})'.format(flag))
 
 
 def main():
@@ -50,8 +51,9 @@ def main():
     )
 
     ctx = config.new_context_from_file(args['--config-file'])
-    helpers.connect(ctx)
+    connection.connect(ctx)
     flag(ctx, args['<mail_id>'], args['<flag>'], directory=args['<directory>'])
+    connection.disconnect(ctx)
     return 0
 
 
